summaryrefslogtreecommitdiffstats
path: root/kword/KWTextFrameSet.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /kword/KWTextFrameSet.cpp
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kword/KWTextFrameSet.cpp')
-rw-r--r--kword/KWTextFrameSet.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kword/KWTextFrameSet.cpp b/kword/KWTextFrameSet.cpp
index 54f9f97d..540794f1 100644
--- a/kword/KWTextFrameSet.cpp
+++ b/kword/KWTextFrameSet.cpp
@@ -396,7 +396,7 @@ KWFrame * KWTextFrameSet::internalToDocumentWithHint( const TQPoint &iPoint, KoP
kdDebug() << "ITD: r=" << r << " iPoint=" << iPoint.x() << "," << iPoint.y() << endl;
#endif
// r is the frame in qrt coords
- if ( r.contains( iPoint ) ) // both r and p are in tqlayout units (aka internal)
+ if ( r.contains( iPoint ) ) // both r and p are in layout units (aka internal)
{
dPoint = internalToDocumentKnowingFrame( iPoint, theFrame );
#ifdef DEBUG_ITD
@@ -757,7 +757,7 @@ void KWTextFrameSet::drawCursor( TQPainter *p, KoTextCursor *cursor, bool cursor
#endif
p->save();
- TQColorGroup cg = TQApplication::tqpalette().active();
+ TQColorGroup cg = TQApplication::palette().active();
if ( hasFrames )
{
@@ -824,7 +824,7 @@ void KWTextFrameSet::drawCursor( TQPainter *p, KoTextCursor *cursor, bool cursor
m_currentDrawnFrame = 0L;
}
-void KWTextFrameSet::tqlayout()
+void KWTextFrameSet::layout()
{
invalidate();
// Get the thing going though, repainting doesn't call formatMore
@@ -835,7 +835,7 @@ void KWTextFrameSet::invalidate()
{
//kdDebug() << "KWTextFrameSet::invalidate " << name() << endl;
m_textobj->setLastFormattedParag( textDocument()->firstParag() );
- textDocument()->invalidate(); // lazy tqlayout, real update follows upon next repaint
+ textDocument()->invalidate(); // lazy layout, real update follows upon next repaint
}
void KWTextFrameSet::slotRepaintChanged()
@@ -960,7 +960,7 @@ void KWTextFrameSet::getMargins( int yp, int h, int reqMinWidth,
if ( validHeight )
*validHeight = h; // TODO
// Everything from there is in tqlayout units
// Note: it is very important that this method works in internal coordinates.
// Otherwise, parags broken at the line-level (e.g. between two columns) are seen
// as still in one piece, and we miss the frames in the 2nd column.
@@ -1984,7 +1984,7 @@ bool KWTextFrameSet::slotAfterFormattingNeedMoreSpace( int bottom, KoTextParag *
frmBehavior = KWFrame::Ignore;
}
- int difference = ( bottom + 2 ) - availHeight; // in tqlayout unit pixels
+ int difference = ( bottom + 2 ) - availHeight; // in layout unit pixels
#ifdef DEBUG_FORMAT_MORE
kdDebug(32002) << "AutoExtendFrame bottom=" << bottom << " availHeight=" << availHeight
<< " => difference = " << difference << endl;
@@ -2484,7 +2484,7 @@ void KWTextFrameSet::frameResized( KWFrame *theFrame, bool invalidateLayout )
m_doc->recalcFrames( theFrame->pageNumber(), -1 ); // warning this can delete theFrame!
// m_doc->frameChanged( theFrame );
// Warning, can't call tqlayout() (frameChanged calls it)
// from here, since it calls formatMore() !
if ( invalidateLayout )
m_doc->invalidate(this);
@@ -2770,7 +2770,7 @@ bool KWTextFrameSet::minMaxInternalOnPage( int pageNum, int& topLU, int& bottomL
topPt = TQMIN( topPt, y );
bottomPt = TQMAX( bottomPt, y + frameIt.current()->height() );
}
// Convert to tqlayout units
topLU = m_doc->ptToLayoutUnitPixY( topPt );
bottomLU = m_doc->ptToLayoutUnitPixY( bottomPt );
return true;
@@ -3146,7 +3146,7 @@ void KWTextFrameSetEdit::slotFrameDeleted( KWFrame *frm )
void KWTextFrameSetEdit::paste()
{
- TQMimeSource *data = TQApplication::tqclipboard()->data();
+ TQMimeSource *data = TQApplication::clipboard()->data();
int provides = KWView::checkClipboard( data );
pasteData( data, provides, false );
}
@@ -3163,7 +3163,7 @@ void KWTextFrameSetEdit::pasteData( TQMimeSource* data, int provides, bool drop
{
// Note: TQClipboard::text() seems to do a better job than encodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
- const TQString text = TQApplication::tqclipboard()->text();
+ const TQString text = TQApplication::clipboard()->text();
const bool removeSelected = !drop;
if ( !text.isEmpty() )
textObject()->pasteText( cursor(), text, currentFormat(), removeSelected );
@@ -3208,7 +3208,7 @@ void KWTextFrameSetEdit::copy()
{
if ( textDocument()->hasSelection( KoTextDocument::Standard ) ) {
TQDragObject *drag = newDrag( 0 );
- TQApplication::tqclipboard()->setData( drag );
+ TQApplication::clipboard()->setData( drag );
}
}
@@ -3652,9 +3652,9 @@ void KWTextFrameSetEdit::dropEvent( TQDropEvent * e, const TQPoint & nPoint, con
cmd = pasteOasisCommand( e );
if ( cmd )
macroCmd->addCommand(cmd);
- //retqlayout textframeset after a dnd otherwise autoextend
+ //relayout textframeset after a dnd otherwise autoextend
//frameset is not re-layouted
- textFrameSet()->tqlayout();
+ textFrameSet()->layout();
frameSet()->kWordDocument()->addCommand( macroCmd );
}
return;
@@ -960,7 +960,7 @@ void KWTextFrameSet::getMargins( int yp, int h, int reqMinWidth,
if ( validHeight )
*validHeight = h; // TODO
- // Everything from there is in tqlayout units
+ // Everything from there is in layout units
// Note: it is very important that this method works in internal coordinates.
// Otherwise, parags broken at the line-level (e.g. between two columns) are seen
@@ -2484,7 +2484,7 @@ void KWTextFrameSet::frameResized( KWFrame *theFrame, bool invalidateLayout )
m_doc->recalcFrames( theFrame->pageNumber(), -1 ); // warning this can delete theFrame!
// m_doc->frameChanged( theFrame );
- // Warning, can't call tqlayout() (frameChanged calls it)
+ // Warning, can't call layout() (frameChanged calls it)
// from here, since it calls formatMore() !
if ( invalidateLayout )
@@ -2770,7 +2770,7 @@ bool KWTextFrameSet::minMaxInternalOnPage( int pageNum, int& topLU, int& bottomL
bottomPt = TQMAX( bottomPt, y + frameIt.current()->height() );
}
- // Convert to tqlayout units
+ // Convert to layout units
topLU = m_doc->ptToLayoutUnitPixY( topPt );
bottomLU = m_doc->ptToLayoutUnitPixY( bottomPt );